@@ -1,7 +1,8 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.TimestampVariables import TimestampVariables as vars
 import datetime as dt
 
-class Timestamp:
+class Timestamp(FTSProtocolObject):
     def __init__(self):
         self.INTAG = None
 
